@@ -98,11 +98,21 @@ types: list[str] = [
     "AWS::Batch::JobDefinition",
     "AWS::Batch::JobQueue",
     "AWS::Batch::SchedulingPolicy",
+    "AWS::Bedrock::Agent",
+    "AWS::Bedrock::AgentAlias",
+    "AWS::Bedrock::DataSource",
+    "AWS::Bedrock::Flow",
+    "AWS::Bedrock::FlowAlias",
+    "AWS::Bedrock::FlowVersion",
     "AWS::Bedrock::Guardrail",
     "AWS::Bedrock::GuardrailVersion",
+    "AWS::Bedrock::KnowledgeBase",
+    "AWS::Bedrock::Prompt",
+    "AWS::Bedrock::PromptVersion",
     "AWS::CDK::Metadata",
     "AWS::Cassandra::Keyspace",
     "AWS::Cassandra::Table",
+    "AWS::Cassandra::Type",
     "AWS::CertificateManager::Account",
     "AWS::CertificateManager::Certificate",
     "AWS::CloudFormation::CustomResource",
@@ -338,6 +348,7 @@ types: list[str] = [
     "AWS::EMR::Step",
     "AWS::EMR::Studio",
     "AWS::EMR::StudioSessionMapping",
+    "AWS::EMRContainers::VirtualCluster",
     "AWS::ElastiCache::CacheCluster",
     "AWS::ElastiCache::GlobalReplicationGroup",
     "AWS::ElastiCache::ParameterGroup",
@@ -499,6 +510,7 @@ types: list[str] = [
     "AWS::KMS::Alias",
     "AWS::KMS::Key",
     "AWS::KMS::ReplicaKey",
+    "AWS::Kinesis::ResourcePolicy",
     "AWS::Kinesis::Stream",
     "AWS::Kinesis::StreamConsumer",
     "AWS::KinesisAnalytics::Application",
@@ -547,6 +559,7 @@ types: list[str] = [
     "AWS::Logs::ResourcePolicy",
     "AWS::Logs::SubscriptionFilter",
     "AWS::M2::Application",
+    "AWS::M2::Deployment",
     "AWS::M2::Environment",
     "AWS::MSK::BatchScramSecret",
     "AWS::MSK::Cluster",
@@ -610,6 +623,7 @@ types: list[str] = [
     "AWS::Pinpoint::SmsTemplate",
     "AWS::Pinpoint::VoiceChannel",
     "AWS::QuickSight::Analysis",
+    "AWS::QuickSight::CustomPermissions",
     "AWS::QuickSight::Dashboard",
     "AWS::QuickSight::DataSet",
     "AWS::QuickSight::DataSource",
@@ -856,7 +870,6 @@ cached: list[str] = [
     "aws-apigatewayv2-stage.json",
     "aws-appconfig-application.json",
     "aws-appconfig-configurationprofile.json",
-    "aws-appconfig-deployment.json",
     "aws-appconfig-deploymentstrategy.json",
     "aws-appconfig-environment.json",
     "aws-appconfig-extension.json",
@@ -898,9 +911,20 @@ cached: list[str] = [
     "aws-batch-jobdefinition.json",
     "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
+    "aws-bedrock-agent.json",
+    "aws-bedrock-agentalias.json",
+    "aws-bedrock-datasource.json",
+    "aws-bedrock-flow.json",
+    "aws-bedrock-flowalias.json",
+    "aws-bedrock-flowversion.json",
     "aws-bedrock-guardrail.json",
     "aws-bedrock-guardrailversion.json",
+    "aws-bedrock-knowledgebase.json",
+    "aws-bedrock-prompt.json",
+    "aws-bedrock-promptversion.json",
+    "aws-cassandra-keyspace.json",
     "aws-cassandra-table.json",
+    "aws-cassandra-type.json",
     "aws-certificatemanager-account.json",
     "aws-certificatemanager-certificate.json",
     "aws-cloudformation-customresource.json",
@@ -1010,12 +1034,13 @@ cached: list[str] = [
     "aws-docdb-dbinstance.json",
     "aws-docdb-dbsubnetgroup.json",
     "aws-docdb-eventsubscription.json",
-    "aws-dynamodb-globaltable.json",
+    "aws-dynamodb-table.json",
     "aws-ec2-capacityreservation.json",
     "aws-ec2-capacityreservationfleet.json",
     "aws-ec2-clientvpnendpoint.json",
     "aws-ec2-clientvpnroute.json",
     "aws-ec2-clientvpntargetnetworkassociation.json",
+    "aws-ec2-customergateway.json",
     "aws-ec2-dhcpoptions.json",
     "aws-ec2-ec2fleet.json",
     "aws-ec2-egressonlyinternetgateway.json",
@@ -1025,6 +1050,7 @@ cached: list[str] = [
     "aws-ec2-gatewayroutetableassociation.json",
     "aws-ec2-instance.json",
     "aws-ec2-instanceconnectendpoint.json",
+    "aws-ec2-internetgateway.json",
     "aws-ec2-ipam.json",
     "aws-ec2-ipamallocation.json",
     "aws-ec2-ipampool.json",
@@ -1041,6 +1067,7 @@ cached: list[str] = [
     "aws-ec2-natgateway.json",
     "aws-ec2-networkacl.json",
     "aws-ec2-networkaclentry.json",
+    "aws-ec2-networkinterface.json",
     "aws-ec2-networkinterfacepermission.json",
     "aws-ec2-placementgroup.json",
     "aws-ec2-prefixlist.json",
@@ -1081,7 +1108,6 @@ cached: list[str] = [
     "aws-ec2-vpc.json",
     "aws-ec2-vpcblockpublicaccessexclusion.json",
     "aws-ec2-vpcblockpublicaccessoptions.json",
-    "aws-ec2-vpccidrblock.json",
     "aws-ec2-vpcdhcpoptionsassociation.json",
     "aws-ec2-vpcendpointconnectionnotification.json",
     "aws-ec2-vpcendpointservice.json",
@@ -1111,6 +1137,7 @@ cached: list[str] = [
     "aws-elasticache-replicationgroup.json",
     "aws-elasticache-securitygroup.json",
     "aws-elasticache-securitygroupingress.json",
+    "aws-elasticache-serverlesscache.json",
     "aws-elasticache-user.json",
     "aws-elasticloadbalancing-loadbalancer.json",
     "aws-elasticloadbalancingv2-listener.json",
@@ -1124,8 +1151,7 @@ cached: list[str] = [
     "aws-emr-cluster.json",
     "aws-emr-instancefleetconfig.json",
     "aws-emr-instancegroupconfig.json",
-    "aws-emr-studio.json",
-    "aws-emr-studiosessionmapping.json",
+    "aws-emrcontainers-virtualcluster.json",
     "aws-events-archive.json",
     "aws-events-eventbuspolicy.json",
     "aws-eventschemas-discoverer.json",
@@ -1228,6 +1254,7 @@ cached: list[str] = [
     "aws-iotevents-alarmmodel.json",
     "aws-iotevents-detectormodel.json",
     "aws-iotevents-input.json",
+    "aws-iotsitewise-accesspolicy.json",
     "aws-iotsitewise-asset.json",
     "aws-iotsitewise-assetmodel.json",
     "aws-iotsitewise-dashboard.json",
@@ -1238,6 +1265,8 @@ cached: list[str] = [
     "aws-iottwinmaker-scene.json",
     "aws-iottwinmaker-syncjob.json",
     "aws-iottwinmaker-workspace.json",
+    "aws-kinesis-resourcepolicy.json",
+    "aws-kinesis-stream.json",
     "aws-kinesis-streamconsumer.json",
     "aws-kinesisanalytics-applicationoutput.json",
     "aws-kinesisanalyticsv2-application.json",
@@ -1273,8 +1302,14 @@ cached: list[str] = [
     "aws-logs-deliverydestination.json",
     "aws-logs-deliverysource.json",
     "aws-logs-destination.json",
+    "aws-logs-loggroup.json",
     "aws-logs-logstream.json",
+    "aws-logs-metricfilter.json",
+    "aws-logs-querydefinition.json",
     "aws-logs-resourcepolicy.json",
+    "aws-logs-subscriptionfilter.json",
+    "aws-m2-application.json",
+    "aws-m2-deployment.json",
     "aws-msk-batchscramsecret.json",
     "aws-msk-cluster.json",
     "aws-msk-clusterpolicy.json",
@@ -1310,6 +1345,7 @@ cached: list[str] = [
     "aws-opsworks-volume.json",
     "aws-organizations-organization.json",
     "aws-organizations-organizationalunit.json",
+    "aws-organizations-policy.json",
     "aws-organizations-resourcepolicy.json",
     "aws-pinpoint-apnschannel.json",
     "aws-pinpoint-apnssandboxchannel.json",
@@ -1327,8 +1363,8 @@ cached: list[str] = [
     "aws-pinpoint-smstemplate.json",
     "aws-pinpoint-voicechannel.json",
     "aws-quicksight-analysis.json",
+    "aws-quicksight-custompermissions.json",
     "aws-quicksight-dashboard.json",
-    "aws-quicksight-dataset.json",
     "aws-quicksight-datasource.json",
     "aws-quicksight-folder.json",
     "aws-quicksight-refreshschedule.json",
@@ -1337,8 +1373,13 @@ cached: list[str] = [
     "aws-quicksight-vpcconnection.json",
     "aws-ram-permission.json",
     "aws-rbin-rule.json",
+    "aws-rds-dbclusterparametergroup.json",
+    "aws-rds-dbparametergroup.json",
     "aws-rds-dbsecuritygroup.json",
     "aws-rds-dbsecuritygroupingress.json",
+    "aws-rds-dbsubnetgroup.json",
+    "aws-rds-eventsubscription.json",
+    "aws-rds-optiongroup.json",
     "aws-redshift-cluster.json",
     "aws-redshift-clusterparametergroup.json",
     "aws-redshift-clustersecuritygroup.json",
@@ -1347,7 +1388,6 @@ cached: list[str] = [
     "aws-redshift-endpointaccess.json",
     "aws-redshift-endpointauthorization.json",
     "aws-redshift-eventsubscription.json",
-    "aws-redshift-integration.json",
     "aws-redshift-scheduledaction.json",
     "aws-redshiftserverless-namespace.json",
     "aws-rekognition-collection.json",
@@ -1359,12 +1399,12 @@ cached: list[str] = [
     "aws-robomaker-simulationapplication.json",
     "aws-robomaker-simulationapplicationversion.json",
     "aws-rolesanywhere-crl.json",
-    "aws-rolesanywhere-profile.json",
     "aws-rolesanywhere-trustanchor.json",
     "aws-route53-recordset.json",
     "aws-route53-recordsetgroup.json",
     "aws-route53profiles-profile.json",
     "aws-route53resolver-firewalldomainlist.json",
+    "aws-route53resolver-firewallrulegroup.json",
     "aws-route53resolver-firewallrulegroupassociation.json",
     "aws-route53resolver-resolverconfig.json",
     "aws-route53resolver-resolverdnssecconfig.json",
@@ -1440,7 +1480,7 @@ cached: list[str] = [
     "aws-servicediscovery-instance.json",
     "aws-servicediscovery-privatednsnamespace.json",
     "aws-servicediscovery-publicdnsnamespace.json",
-    "aws-ses-configurationset.json",
+    "aws-servicediscovery-service.json",
     "aws-ses-configurationseteventdestination.json",
     "aws-ses-contactlist.json",
     "aws-ses-dedicatedippool.json",
@@ -1499,6 +1539,7 @@ cached: list[str] = [
     "aws-wafv2-loggingconfiguration.json",
     "aws-wafv2-webaclassociation.json",
     "aws-workspaces-workspace.json",
+    "aws-workspaces-workspacespool.json",
     "aws-xray-resourcepolicy.json",
     "module.json",
 ]
