@@ -61,6 +61,11 @@ AVAILABILITY_ZONES = {
         "ap-southeast-5b",
         "ap-southeast-5c",
     ],
+    "ap-southeast-7": [
+        "ap-southeast-7a",
+        "ap-southeast-7b",
+        "ap-southeast-7c",
+    ],
     "ca-west-1": [
         "ca-west-1a",
         "ca-west-1b",
@@ -136,7 +141,7 @@ REGEX_DYN_REF_SSM = re.compile(r"^.*{{resolve:ssm:[a-zA-Z0-9_\.\-/]+(:\d+)?}}.*$
 REGEX_DYN_REF_SSM_SECURE = re.compile(
     r"^.*{{resolve:ssm-secure:[a-zA-Z0-9_\.\-/]+(:\d+)?}}.*$"
 )
-REGEX_SUB_PARAMETERS = re.compile(r"\${([^!].*?)}")
+REGEX_SUB_PARAMETERS = re.compile(r"\${\s*([^!\s].*?)\s*}")
 
 FUNCTIONS = frozenset(
     [
